@@ -5,9 +5,8 @@ test_that ("c-method", {
                x1 <- osmdata_sf (q, "../osm-multi.osm")
                x2 <- osmdata_sf (q, "../osm-ways.osm")
                x <- c (x1, x2)
-               osm_indx <- which (grepl ('osm_', names (x)))
-               for (i in osm_indx)
-               {
+               osm_indx <- which (grepl ("osm_", names (x)))
+               for (i in osm_indx) {
                    expect_true (nrow (x [[i]]) >= nrow (x1 [[i]]))
                    if (!is.null (x2 [[i]])) 
                        expect_true (nrow (x [[i]]) >= nrow (x2 [[i]]))
